.. _tasks:

Tasks
=====
This section gives you ideas about the kind of tasks you can use Rubrix for. It also describes some of the tasks on our roadmap, if there's some task you want and don't see here or you want to contribute a task, file an issue or use the Discussion forum at `Rubrix's GitHub page <https://github.com/recognai/rubrix/>`_.

Supported tasks
---------------

Text classification
^^^^^^^^^^^^^^^^^^^

According to the amazing `NLP Progress resource by Seb Ruder <http://nlpprogress.com/english/text_classification.html>`_:

..

   Text classification is the task of assigning a sentence or document an appropriate category. The categories depend on the chosen dataset and can range from topics.




Rubrix is flexible with input and output shapes, which means you can model many related tasks like for example:

* `Sentiment analysis <http://nlpprogress.com/english/sentiment_analysis.html>`_ 
* `Natural Language Inference <http://nlpprogress.com/english/natural_language_inference.html>`_
* `Semantic Textual Similarity <https://paperswithcode.com/task/semantic-textual-similarity>`_
* `Stance detection <http://nlpprogress.com/english/stance_detection.html>`_
* **Multi-label text classification**
* **Node classification in knowledge graphs**.

Token classification
^^^^^^^^^^^^^^^^^^^^

The most well-known task in this category is probably `Named Entity Recognition <http://nlpprogress.com/english/named_entity_recognition.html>`_:

..

   Named entity recognition (NER) is the task of tagging entities in text with their corresponding type. Approaches typically use BIO notation, which differentiates the beginning (B) and the inside (I) of entities. O is used for non-entity tokens.




Rubrix is flexible with input and output shapes, which means you can model related tasks like for example:


* Named entity recognition
* Part of speech tagging
* Slot filling

Tasks on the roadmap
--------------------

Natural language processing
^^^^^^^^^^^^^^^^^^^^^^^^^^^


* Text2Text, covering summarization, machine translation, natural language generation, etc.
* Question answering
* `Keyphrase extraction <https://paperswithcode.com/task/keyword-extraction>`_
* `Relationship Extraction <http://nlpprogress.com/english/relationship_extraction.html>`_

Computer vision
^^^^^^^^^^^^^^^


* Image classification
* Image captioning

Speech
^^^^^^


* Speech2Text
